@@ -53,7 +53,7 @@ class Instance(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["InstanceProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[InstanceProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -140,7 +140,7 @@ class InstanceProps:
                 duration: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
                 pricing_cycle: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
                 promotion_code: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-                resource_spec: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosInstance.ResourceSpecProperty", typing.Dict[str, typing.Any]]]] = None,
+                resource_spec: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosInstance.ResourceSpecProperty, typing.Dict[str, typing.Any]]]] = None,
                 use_promotion_code: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
             ) -> None:
                 ...
@@ -325,7 +325,7 @@ class Namespace(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["NamespaceProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[NamespaceProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -377,7 +377,7 @@ class NamespaceProps:
                 *,
                 instance_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
                 namespace: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-                resource_spec: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosNamespace.ResourceSpecProperty", typing.Dict[str, typing.Any]]]] = None,
+                resource_spec: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosNamespace.ResourceSpecProperty, typing.Dict[str, typing.Any]]]] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -450,7 +450,7 @@ class RosInstance(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosInstanceProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosInstanceProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -780,7 +780,7 @@ class RosInstance(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.ResourceSpecProperty"]],
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosInstance.ResourceSpecProperty]],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -1156,7 +1156,7 @@ class RosNamespace(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosNamespaceProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosNamespaceProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -1284,7 +1284,7 @@ class RosNamespace(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosNamespace.ResourceSpecProperty"]],
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosNamespace.ResourceSpecProperty]],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
